==> casper7_plugin_wordle_reactions-0.1.2-py3-none-any.whl: casper7_plugin_wordle_reactions/run.py <==
"""
a casper7 plugin that reacts to wordle results

Usage:
    casper7-plugin-wordle-reactions [options] react [--] <args>
    casper7-plugin-wordle-reactions --listeners
    casper7-plugin-wordle-reactions --commands
    casper7-plugin-wordle-reactions --jobs
    casper7-plugin-wordle-reactions (-h | --help)
    casper7-plugin-wordle-reactions --version

Options:
    -g --guild GUILD_ID         Guild ID the message is coming from.
    -c --channel CHANNEL_ID     Channel ID the message is coming from.
    -u --user USER_ID           User ID the message is coming from.
    -m --message MESSAGE_ID     ID of the message that was sent.
    --listeners                 Get listener config JSON.
    --commands                  Get command config JSON.
    --jobs                      Get job config JSON.
    -h --help                   Show this screen.
    --version                   Show version.
"""
import json
import re
from importlib.metadata import version

from docopt import docopt

from casper7_plugin_wordle_reactions.settings import settings

reactions = [
    (re.compile(r"wordle \d+ [1-6]/6"), ":brain:"),
    (re.compile(r"wordle \d+ X/6"), ":snail:"),
    (re.compile(r"daily duotrigordle #\d+\nguesses: \d+/37"), ":brain:"),
    (re.compile(r"daily duotrigordle #\d+\nguesses: X/37"), ":snail:"),
    (re.compile(r"scholardle \d+ [1-6]/6"), ":mortar_board:"),
    (re.compile(r"scholardle \d+ X/6"), ":snail:"),
    (re.compile(r"worldle #\d+ [1-6]/6 \(100%\)"), ":map"),
    (re.compile(r"worldle #\d+ X/6 \(\d+%\)"), ":snail:"),
    (re.compile(r"waffle\d+ [0-5]/5"), ":waffle:"),
    (re.compile(r"waffle\d+ 5/5"), ":star:"),
    (re.compile(r"waffle\d+ X/5"), ":snail:"),
    (re.compile(r"#wafflesilverteam"), ":second_place:"),
    (re.compile(r"#wafflegoldteam"), ":first_place:"),
    (re.compile(r"flowdle \d+ \[\d+ moves\]"), ":potable_water:"),
    (re.compile(r"jurassic wordle \(game #\d+\) - [1-8] / 8"), ":sauropod:"),
    (re.compile(r"jurassic wordle \(game #\d+\) - X / 8"), ":snail:"),
    (re.compile(r"jungdle \(game #\d+\) - [1-8] / 8"), ":lion:"),
    (re.compile(r"jungdle \(game #\d+\) - X / 8"), ":snail:"),
    (re.compile(r"dogsdle \(game #\d+\) - [1-8] / 8"), ":dog:"),
    (re.compile(r"dogsdle \(game #\d+\) - X / 8"), ":snail:"),
    # TODO: framed
    # TODO: moviedle
    # TODO: posterdle
    # TODO: namethatride
    # TODO: heardle
]


def print_listeners() -> None:
    """Print listener config JSON."""
    print(
        json.dumps(
            [
                {
                    "name": "react",
                }
            ]
        )
    )


def maybe_react(message: str, *, channel_id: int, message_id: int) -> None:
    """Check if a message contains any known patterns and emit add_reaction events."""
    if channel_id not in settings.wordle_channels:
        return

    events = []
    for pattern, emoji in reactions:
        if pattern.search(message):
            events.append(
                {
                    "type": "add_reaction",
                    "channel_id": channel_id,
                    "message_id": message_id,
                    "emoji": emoji,
                }
            )
    print(json.dumps(events))


def plugin() -> None:
    """Plugin entrypoint."""
    args = docopt(
        __doc__, version=f"casper7-plugin-wordle-reactions {version(__package__)}"
    )

    if args["<args>"]:
        args["<args>"] = json.loads(args["<args>"])

    channel_id = args["--channel"]
    message_id = args["--message"]

    match args:
        case {"--listeners": True}:
            print_listeners()
        case {"--commands": True}:
            print("[]")
        case {"--jobs": True}:
            print("[]")
        case {"react": True, "<args>": {"message": message}}:
            maybe_react(message, channel_id=channel_id, message_id=message_id)

==> casper7_plugin_wordle_reactions-0.1.3-py3-none-any.whl: casper7_plugin_wordle_reactions/run.py <==
"""
a casper7 plugin that reacts to wordle results

Usage:
    casper7-plugin-wordle-reactions [options] react [--] <args>
    casper7-plugin-wordle-reactions --listeners
    casper7-plugin-wordle-reactions --commands
    casper7-plugin-wordle-reactions --jobs
    casper7-plugin-wordle-reactions (-h | --help)
    casper7-plugin-wordle-reactions --version

Options:
    -g --guild GUILD_ID         Guild ID the message is coming from.
    -c --channel CHANNEL_ID     Channel ID the message is coming from.
    -u --user USER_ID           User ID the message is coming from.
    -m --message MESSAGE_ID     ID of the message that was sent.
    --listeners                 Get listener config JSON.
    --commands                  Get command config JSON.
    --jobs                      Get job config JSON.
    -h --help                   Show this screen.
    --version                   Show version.
"""
import json
import re
from importlib.metadata import version

from docopt import docopt

from casper7_plugin_wordle_reactions.settings import settings


def re_compile(pattern: str) -> re.Pattern:
    """Compile a regex pattern."""
    return re.compile(pattern, re.IGNORECASE | re.MULTILINE)


reactions = [
    (re_compile(r"wordle \d+ [1-6]/6"), ":brain:"),
    (re_compile(r"wordle \d+ X/6"), ":snail:"),
    (re_compile(r"daily duotrigordle #\d+\nguesses: \d+/37"), ":brain:"),
    (re_compile(r"daily duotrigordle #\d+\nguesses: X/37"), ":snail:"),
    (re_compile(r"scholardle \d+ [1-6]/6"), ":mortar_board:"),
    (re_compile(r"scholardle \d+ X/6"), ":snail:"),
    (re_compile(r"worldle #\d+ [1-6]/6 \(100%\)"), ":map"),
    (re_compile(r"worldle #\d+ X/6 \(\d+%\)"), ":snail:"),
    (re_compile(r"waffle\d+ [0-5]/5"), ":waffle:"),
    (re_compile(r"waffle\d+ 5/5"), ":star:"),
    (re_compile(r"waffle\d+ X/5"), ":snail:"),
    (re_compile(r"#wafflesilverteam"), ":second_place:"),
    (re_compile(r"#wafflegoldteam"), ":first_place:"),
    (re_compile(r"flowdle \d+ \[\d+ moves\]"), ":potable_water:"),
    (re_compile(r"jurassic wordle \(game #\d+\) - [1-8] / 8"), ":sauropod:"),
    (re_compile(r"jurassic wordle \(game #\d+\) - X / 8"), ":snail:"),
    (re_compile(r"jungdle \(game #\d+\) - [1-8] / 8"), ":lion:"),
    (re_compile(r"jungdle \(game #\d+\) - X / 8"), ":snail:"),
    (re_compile(r"dogsdle \(game #\d+\) - [1-8] / 8"), ":dog:"),
    (re_compile(r"dogsdle \(game #\d+\) - X / 8"), ":snail:"),
    # TODO: framed
    # TODO: moviedle
    # TODO: posterdle
    # TODO: namethatride
    # TODO: heardle
]


def print_listeners() -> None:
    """Print listener config JSON."""
    print(
        json.dumps(
            [
                {
                    "name": "react",
                }
            ]
        )
    )


def maybe_react(message: str, *, channel_id: str, message_id: str) -> None:
    """Check if a message contains any known patterns and emit add_reaction events."""
    if channel_id not in settings.wordle_channels:
        return

    events = []
    for pattern, emoji in reactions:
        if pattern.search(message):
            events.append(
                {
                    "type": "add_reaction",
                    "channel_id": channel_id,
                    "message_id": message_id,
                    "emoji": emoji,
                }
            )
    print(json.dumps(events))


def plugin() -> None:
    """Plugin entrypoint."""
    args = docopt(
        __doc__, version=f"casper7-plugin-wordle-reactions {version(__package__)}"
    )

    if args["<args>"]:
        args["<args>"] = json.loads(args["<args>"])

    channel_id = args["--channel"]
    message_id = args["--message"]

    match args:
        case {"--listeners": True}:
            print_listeners()
        case {"--commands": True}:
            print("[]")
        case {"--jobs": True}:
            print("[]")
        case {"react": True, "<args>": {"message": message}}:
            maybe_react(message, channel_id=channel_id, message_id=message_id)
